Class: Device::Runtime
- Inherits:
-
Object
- Object
- Device::Runtime
- Defined in:
- lib/device/runtime.rb
Class Method Summary collapse
- .adapter ⇒ Object
-
.execute(app, json = nil) ⇒ Object
Execute app in new context.
-
.system_reload ⇒ NilClass
Check if any change has happen to Network, Settings or ParamsDat.
Class Method Details
.adapter ⇒ Object
3 4 5 |
# File 'lib/device/runtime.rb', line 3 def self.adapter Device.adapter::Runtime end |
.execute(app, json = nil) ⇒ Object
Execute app in new context.
To execute the should exists a zip file cotain the app,
previously downloaded from CloudWalk.
14 15 16 17 18 |
# File 'lib/device/runtime.rb', line 14 def self.execute(app, json = nil) execution_ret = mrb_eval("Context.start('#{app}', '#{Device.adapter}', '#{json}')") self.system_reload return execution_ret end |